============
Django Filer
============

|pypi| |build| |coverage|

**django Filer** is a file management application for django that makes
handling of files and images a breeze.

.. We're using absolute image url below, because relative paths won't work on
   pypi. github would render relative paths correctly.

+--------------------------------------------------------------------------------------------------------+--------------------------------------------------------------------------------------------------------+
| .. image:: https://raw.githubusercontent.com/divio/django-filer/master/docs/_static/filer_2.png        | .. image:: https://raw.githubusercontent.com/divio/django-filer/master/docs/_static/filer_3.png        |
+--------------------------------------------------------------------------------------------------------+--------------------------------------------------------------------------------------------------------+
| .. image:: https://raw.githubusercontent.com/divio/django-filer/master/docs/_static/detail_image.png   | .. image:: https://raw.githubusercontent.com/divio/django-filer/master/docs/_static/detail_file.png    |
+--------------------------------------------------------------------------------------------------------+--------------------------------------------------------------------------------------------------------+
| .. image:: https://raw.githubusercontent.com/divio/django-filer/master/docs/_static/file_picker_1.png  | .. image:: https://raw.githubusercontent.com/divio/django-filer/master/docs/_static/file_picker_3.png  |
+--------------------------------------------------------------------------------------------------------+--------------------------------------------------------------------------------------------------------+


Contributing
============

This is a an open-source project. We'll be delighted to receive your
feedback in the form of issues and pull requests. Before submitting your
pull request, please review our `contribution guidelines
<http://docs.django-cms.org/en/latest/contributing/index.html>`_.

We're grateful to all contributors who have helped create and maintain this package.
Contributors are listed at the `contributors <https://github.com/divio/django-filer/graphs/contributors>`_
section.

One of the easiest contributions you can make is helping to translate this addon on
`Transifex <https://www.transifex.com/projects/p/django-filer/>`_.


Documentation
=============

Please head over to the separate `documentation <https://django-filer.readthedocs.io/en/latest/index.html>`_
for all the details on how to install, configure and use django-filer.

|python| |django|


.. |pypi| image:: https://badge.fury.io/py/django-filer.svg
    :target: http://badge.fury.io/py/django-filer
.. |build| image:: https://travis-ci.org/divio/django-filer.svg?branch=master
    :target: https://travis-ci.org/divio/django-filer
.. |coverage| image:: https://codecov.io/gh/divio/django-filer/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/divio/django-filer

.. |python| image:: https://img.shields.io/badge/python-3.5+-blue.svg
    :target: https://pypi.org/project/django-filer/
.. |django| image:: https://img.shields.io/badge/django-2.2,%203.0,%203.1-blue.svg
    :target: https://www.djangoproject.com/
